pyhsm.validate_cmd.YHSM_ValidationResult

Package pyhsm :: Module validate_cmd :: Class YHSM_ValidationResult |
[frames] | no frames]

# Class YHSM_ValidationResult

The result of a Validate operation.

Contains the counters and timestamps decrypted from the OTP.

Instance Methods
__init__(self, public_id, use_ctr, session_ctr, ts_high, ts_low) |
__repr__(self) |

Instance Variables
integer | ts_low = `None` The low 16 bits of the 24-bit 8 hz timer since power-on of the YubiKey
integer | ts_high = `None` The high 8 bits of the 24-bit 8 hz timer since power-on of the YubiKey
integer | session_ctr = `None` The 8-bit volatile session counter of the YubiKey
integer | use_ctr = `None` The 16-bit power-on non-volatile counter of the YubiKey
string | public_id = `None` The six bytes public ID of the YubiKey that produced the OTP